#ifndef MAZERUNNER_HH
#define MAZERUNNER_HH

//----------------------------------------------------------------------------
// pacman-like game
// copyright 2010 christopher rasmussen
// university of delaware
// v. 1.06
// * added score/time elapsed drawing
// * crossover collisions now detected
// * added wind terrain
// * added blue_ghost_wait_counter
// * starting to move functions, variables over to GameState class; making it const in call to update()
// * added "-blue" option for blue ghosts/no blue ghosts; saving .lay; new quit key
// * moved to MazeRunner.hh

//----------------------------------------------------------------------------

#include "BlockMaze.hh"
#include "Utils.hh"
#include "Agent.hh"
#include "GhostAgent.hh"
#include "RunnerAgent.hh"

//----------------------------------------------------------------------------
//----------------------------------------------------------------------------

#define DO_SPLASH

const char QUIT_KEY           = '/';
const char SAVE_KEY           = '.';

const int CONTINUE_PLAYING    = 0;
const int RUNNER_CAUGHT       = 1;
const int LEVEL_CLEARED       = 2;

const int DEFAULT_ROWS        = 10;
const int DEFAULT_COLS        = 10;

const int NO_BLUE_GHOST       = 0;
const int STANDARD_BLUE_GHOST = 15;

//----------------------------------------------------------------------------
//----------------------------------------------------------------------------

class MazeRunner
{
public:

  MazeRunner(int rows, int cols, int = NO_BLUE_GHOST);
  MazeRunner(string filename, int = NO_BLUE_GHOST);

  void main_loop();

private:

  int update();
  void draw_splash();
  void draw_gameover(int);
  void draw();
  void draw_power_pills();
  bool handle_key();
  void compute_dimensions_lay(ifstream &, int &, int &);
  void load_lay(string);
  void save_lay(string);
  bool check_for_power_pill_eaten(int &);

  int num_updates;              // how many global updates()'s have been called

  BlockMaze *M;                 // the layout of the environment
  vector <Agent *> agent;
  vector <Point_2D> power_pill;
  GameState GS;

  int runner_agent_index;       // where is runner in agent array
  int blue_ghost_time_limit;    // run with "-blue" option to change

};

//----------------------------------------------------------------------------
//----------------------------------------------------------------------------

#endif
